@@ -7,6 +7,7 @@ import pytest
 from astropy.utils.data import download_file
 import vip_hci as vip
 import numpy as np
+import time
 
 
 @pytest.fixture(scope="session")
@@ -101,6 +102,59 @@ def example_dataset_ifs():
     return dataset
 
 
+@pytest.fixture(scope="session")
+def example_dataset_ifs_crop():
+    """
+    Download example FITS cube from github + prepare HCIDataset object, after
+    cropping to only 3 sp. channels (faster NEGFC test).
+
+    Returns
+    -------
+    dataset : HCIDataset
+
+    Notes
+    -----
+    Astropy's ``download_file`` uses caching, so the file is downloaded at most
+    once per test run.
+
+    """
+    print("downloading data...")
+
+    url_prefix = "https://github.com/vortex-exoplanet/VIP_extras/raw/master/datasets"
+
+    f1 = download_file("{}/sphere_v471tau_cube.fits".format(url_prefix),
+                       cache=True)
+    f2 = download_file("{}/sphere_v471tau_psf.fits".format(url_prefix),
+                       cache=True)
+    f3 = download_file("{}/sphere_v471tau_pa.fits".format(url_prefix),
+                       cache=True)
+    f4 = download_file("{}/sphere_v471tau_wl.fits".format(url_prefix),
+                       cache=True)
+
+    # load fits
+    cube = vip.fits.open_fits(f1)
+    cube = cube[-3:]
+    angles = vip.fits.open_fits(f3).flatten()
+    psf = vip.fits.open_fits(f2)
+    psf = psf[-3:]
+    wl = vip.fits.open_fits(f4)
+    wl = wl[-3:]
+
+    # create dataset object
+    dataset = vip.Dataset(cube, angles=angles, psf=psf,
+                          px_scale=vip.config.VLT_SPHERE_IFS['plsc'],
+                          wavelengths=wl)
+
+    # crop
+    dataset.crop_frames(size=100, force=True)
+    dataset.normalize_psf(size=None, force_odd=False)
+
+    # overwrite PSF for easy access
+    dataset.psf = dataset.psfn
+
+    return dataset
+
+
 @pytest.fixture(scope="session")
 def example_dataset_rdi():
     """
@@ -133,9 +187,9 @@ def example_dataset_rdi():
     psf = vip.fits.open_fits(f2)
     # creating a variable flux screen
     scr = vip.var.create_synth_psf('moff', (101, 101), fwhm=50)
-    scrcu = np.array([scr * i for i in np.linspace(-1e2, 1e2, num=31)], 
+    scrcu = np.array([scr * i for i in np.linspace(-1e2, 1e2, num=31)],
                      dtype=np.float32)
-    
+
     # OLD: scaling ?!
     # upscaling (1.2) and taking half of the frames, reversing order
     #cube_upsc = cube_px_resampling(cube[::-1], 1.2, verbose=False)[::2]
@@ -147,9 +201,9 @@ def example_dataset_rdi():
     cube_rot = cube_rot[::2]
     cube_rot = np.flip(cube_rot, axis=1)
     cube_rot = np.flip(cube_rot, axis=2)
-    
+
     # cropping and adding the flux screen
-    cube_ref = cube_rot + scrcu    
+    cube_ref = cube_rot + scrcu
 
     # create dataset object
     dataset = vip.Dataset(cube, angles=angles, psf=psf, cuberef=cube_ref,
@@ -161,3 +215,21 @@ def example_dataset_rdi():
     dataset.psf = dataset.psfn
 
     return dataset
+
+
+@pytest.fixture(autouse=True)
+def time_test():
+    """ Time a test and print out how long it took """
+    before = time.time()
+    yield
+    after = time.time()
+    print(f"Test took {after - before:.02f} seconds!")
+
+
+@pytest.fixture(autouse=True, scope="session")
+def time_all_tests():
+    """ Time a test and print out how long it took """
+    before = time.time()
+    yield
+    after = time.time()
+    print(f"Total test time: {after - before:.02f} seconds!")
