@@ -5,13 +5,14 @@ Module with the function of merit definitions for the NEGFC optimization.
 """
 
 __author__ = 'O. Wertz, Carlos Alberto Gomez Gonzalez, Valentin Christiaens'
-__all__ = []
+__all__ = ['get_mu_and_sigma']
 
 import numpy as np
 from hciplot import plot_frames
 from skimage.draw import disk
 from ..fm import cube_inject_companions
-from ..var import (frame_center, get_annular_wedge, cube_filter_highpass)
+from ..var import (frame_center, get_annular_wedge, cube_filter_highpass,
+                   get_annulus_segments)
 from ..psfsub import pca_annulus, pca_annular, pca
 from ..preproc import cube_crop_frames
 
@@ -306,12 +307,14 @@ def get_values_optimize(cube, angs, ncomp, annulus_width, aperture_radius,
     interpolation = algo_options.get('interpolation', interpolation)
     collapse = algo_options.get('collapse', collapse)
     collapse_ifs = algo_options.get('collapse_ifs', 'absmean')
+    nproc = algo_options.get('nproc', 1)
 
     if algo == pca_annulus:
         res = pca_annulus(cube, angs, ncomp, annulus_width, r_guess, cube_ref,
                           svd_mode, scaling, imlib=imlib,
                           interpolation=interpolation, collapse=collapse,
-                          collapse_ifs=collapse_ifs, weights=weights)
+                          collapse_ifs=collapse_ifs, weights=weights, 
+                          nproc=nproc)
 
     elif algo == pca_annular:
 
@@ -320,7 +323,6 @@ def get_values_optimize(cube, angs, ncomp, annulus_width, aperture_radius,
         max_frames_lib = algo_options.get('max_frames_lib', 200)
         radius_int = max(1, int(np.floor(r_guess-annulus_width/2)))
         radius_int = algo_options.get('radius_int', radius_int)
-        nproc = algo_options.get('nproc', 1)
         # crop cube to just be larger than annulus => FASTER PCA
         crop_sz = int(2*np.ceil(radius_int+annulus_width+1))
         if not crop_sz % 2:
@@ -346,7 +348,6 @@ def get_values_optimize(cube, angs, ncomp, annulus_width, aperture_radius,
     elif algo == pca:
         scale_list = algo_options.get('scale_list', None)
         ifs_collapse_range = algo_options.get('ifs_collapse_range', 'all')
-        nproc = algo_options.get('nproc', 1)
         res = pca(cube, angs, cube_ref, scale_list, ncomp, svd_mode=svd_mode,
                   scaling=scaling, imlib=imlib, interpolation=interpolation,
                   collapse=collapse, collapse_ifs=collapse_ifs,
@@ -357,7 +358,25 @@ def get_values_optimize(cube, angs, ncomp, annulus_width, aperture_radius,
 
     indices = disk((posy, posx), radius=aperture_radius*fwhm)
     yy, xx = indices
-
+    
+    # also consider indices of the annulus for pca_annulus
+    if algo == pca_annulus:
+        fr_size = res.shape[-1]
+        inner_rad = r_guess-annulus_width/2
+        yy_a, xx_a = get_annulus_segments((fr_size, fr_size), inner_rad,
+                                          annulus_width, nsegm=1)[0]
+        ## only consider overlapping indices
+        yy_f = []
+        xx_f = []
+        for i in range(len(yy)):
+            ind_y = np.where(yy_a==yy[i])
+            for j in ind_y[0]:
+                if xx[i]==xx_a[j]:
+                    yy_f.append(yy[i])
+                    xx_f.append(xx[i])
+        yy = np.array(yy_f, dtype=int)
+        xx = np.array(xx_f, dtype=int)
+        
     if collapse is None:
         values = res[:, yy, xx].ravel()
     else:
@@ -558,11 +577,11 @@ def get_mu_and_sigma(cube, angs, ncomp, annulus_width, aperture_radius, fwhm,
 
     if wedge is None:
         delta_theta = np.amax(angs)-np.amin(angs)
-        if delta_theta > 150:
-            delta_theta = 150  # if too much rotation, be less conservative
+        if delta_theta > 120:
+            delta_theta = 120  # if too much rotation, be less conservative
 
         theta_ini = (theta_guess+delta_theta) % 360
-        theta_fin = theta_ini+delta_theta
+        theta_fin = theta_ini+(360-2*delta_theta)
         wedge = (theta_ini, theta_fin)
     elif len(wedge) == 2:
         if wedge[0] > wedge[1]:
