@@ -2,6 +2,7 @@
 
 """
 Module with contrast curve generation function.
+     
 """
 
 __author__ = 'C. Gomez, O. Absil @ ULg'
@@ -27,16 +28,16 @@ from ..var import frame_center, dist
 
 
 def contrast_curve(cube, angle_list, psf_template, fwhm, pxscale, starphot,
-                   algo, sigma=5, nbranch=1, theta=0, inner_rad=1,
-                   wedge=(0, 360), fc_snr=100, student=True, transmission=None,
-                   smooth=True, interp_order=2, plot=True, dpi=vip_figdpi,
-                   debug=False, verbose=True, full_output=False, save_plot=None,
-                   object_name=None, frame_size=None, fix_y_lim=(),
-                   figsize=vip_figsize, **algo_dict):
-    """ Computes the contrast curve at a given SIGMA (``sigma``) level for an
-    ADI cube or ADI+IFS cube. The contrast is calculated as
+                   algo, sigma=5, nbranch=1, theta=0, inner_rad=1, fc_rad_sep=3,
+                   noise_sep=1, wedge=(0, 360), fc_snr=100, student=True, 
+                   transmission=None, smooth=True, interp_order=2, plot=True, 
+                   dpi=vip_figdpi, debug=False, verbose=True, full_output=False, 
+                   save_plot=None, object_name=None, frame_size=None, 
+                   fix_y_lim=(), figsize=vip_figsize, **algo_dict):
+    """ Computes the contrast curve at a given confidence (``sigma``) level for 
+    an ADI cube or ADI+IFS cube. The contrast is calculated as
     sigma*noise/throughput. This implementation takes into account the small
-    sample statistics correction proposed in Mawet et al. 2014.
+    sample statistics correction proposed in [MAW14]_.
 
     Parameters
     ----------
@@ -75,6 +76,16 @@ def contrast_curve(cube, angle_list, psf_template, fwhm, pxscale, starphot,
     inner_rad : int, optional
         Innermost radial distance to be considered in terms of FWHM. Should be
         >= 1.
+    fc_rad_sep : int optional
+        Radial separation between the injected companions (in each of the
+        patterns) in FWHM. Must be large enough to avoid overlapping. With the
+        maximum possible value, a single fake companion will be injected per
+        cube and algorithm post-processing (which greatly affects computation
+        time).
+    noise_sep: int or None, optional
+        Radial sampling of the noise level. By default it is performed with a
+        radial step of 1 pixel. If set to None, it will be automatically set to 
+        be sampled every fwhm pixels radially.
     wedge : tuple of floats, optional
         Initial and Final angles for using a wedge. For example (-90,90) only
         considers the right side of an image.
@@ -186,7 +197,6 @@ def contrast_curve(cube, angle_list, psf_template, fwhm, pxscale, starphot,
         else:
             msg0 = 'ALGO : {}, FWHM = {}, # BRANCHES = {}, SIGMA = {}'
             print(msg0.format(algo.__name__, fwhm_med, nbranch, sigma))
-        print(sep)
 
     # throughput
     verbose_thru = False
@@ -194,8 +204,8 @@ def contrast_curve(cube, angle_list, psf_template, fwhm, pxscale, starphot,
         verbose_thru = True
     res_throug = throughput(cube, angle_list, psf_template, fwhm, algo=algo,
                             nbranch=nbranch, theta=theta, inner_rad=inner_rad,
-                            wedge=wedge, fc_snr=fc_snr, full_output=True,
-                            verbose=verbose_thru, **algo_dict)
+                            fc_rad_sep=fc_rad_sep, wedge=wedge, fc_snr=fc_snr, 
+                            full_output=True, verbose=verbose_thru, **algo_dict)
     vector_radd = res_throug[3]
     if res_throug[0].shape[0] > 1:
         thruput_mean = np.nanmean(res_throug[0], axis=0)
@@ -243,14 +253,19 @@ def contrast_curve(cube, angle_list, psf_template, fwhm, pxscale, starphot,
             ntransmission[1] = np.mean(transmission[1:], axis=0)
             transmission = ntransmission.copy()
 
-    if interp_order is not None:
-        # noise measured in the empty frame with better sampling, every px
-        # starting from 1*FWHM
-        noise_samp, res_lev_samp, rad_samp = noise_per_annulus(frame_nofc,
-                                                               separation=1,
-                                                               fwhm=fwhm_med,
-                                                               init_rad=fwhm_med,
-                                                               wedge=wedge)
+    if interp_order is not None or noise_sep != None:
+        # noise measured in the empty frame with nosie_sep sampling
+        if noise_sep is None:
+            rad_samp = vector_radd
+            noise_samp = res_throug[1]
+            res_lev_samp = res_throug[2]
+        else:
+            # starting from 1*FWHM
+            noise_samp, res_lev_samp, rad_samp = noise_per_annulus(frame_nofc,
+                                                                   separation=noise_sep,
+                                                                   fwhm=fwhm_med,
+                                                                   init_rad=fwhm_med,
+                                                                   wedge=wedge)
         radmin = vector_radd.astype(int).min()
         cutin1 = np.where(rad_samp.astype(int) == radmin)[0][0]
         noise_samp = noise_samp[cutin1:]
@@ -549,6 +564,7 @@ def throughput(cube, angle_list, psf_template, fwhm, algo, nbranch=1, theta=0,
     parangles = angle_list
     imlib = algo_dict.get('imlib', 'vip-fft')
     interpolation = algo_dict.get('interpolation', 'lanczos4')
+    scaling = algo_dict.get('scaling', None)
 
     if array.ndim != 3 and array.ndim != 4:
         raise TypeError('The input array is not a 3d or 4d cube')
@@ -638,9 +654,13 @@ def throughput(cube, angle_list, psf_template, fwhm, algo, nbranch=1, theta=0,
                                                       separation=fwhm_med,
                                                       fwhm=fwhm_med,
                                                       wedge=wedge)
-    noise_noscal, _, _ = noise_per_annulus(frame_nofc_noscal,
-                                           separation=fwhm_med, fwhm=fwhm_med,
-                                           wedge=wedge)
+    if scaling is not None:
+        noise_noscal, _, _ = noise_per_annulus(frame_nofc_noscal,
+                                               separation=fwhm_med, 
+                                               fwhm=fwhm_med, wedge=wedge)
+    else:
+        noise_noscal = noise.copy()
+        
     vector_radd = vector_radd[inner_rad-1:]
     noise = noise[inner_rad-1:]
     res_level = res_level[inner_rad-1:]
@@ -836,8 +856,8 @@ def noise_per_annulus(array, separation, fwhm, init_rad=None, wedge=(0, 360),
     and mean, respectively, of apertures defined in each annulus with a given
     separation.
 
-    The annuli start at init_rad (== fwhm by default) and stop 2*separation
-    before the edge of the frame.
+    The annuli start at init_rad (= fwhm by default if not provided) and stop 
+    2*separation before the edge of the frame.
 
     Parameters
     ----------
