@@ -2,6 +2,22 @@
 
 """
 Module containing functions for cubes frame registration.
+     
+.. [GUI08]
+   | Guizar-Sicairos et al. 2008
+   | **Efficient subpixel image registration algorithms**
+   | *Optics Letters, Volume 33, Issue 2, p. 156*
+   | `https://ui.adsabs.harvard.edu/abs/2008OptL...33..156G
+     <https://ui.adsabs.harvard.edu/abs/2008OptL...33..156G>`_
+     
+.. [PUE15]
+   | Pueyo et al. 2015
+   | **Reconnaissance of the HR 8799 Exosolar System. II. Astrometry and Orbital 
+     Motion**
+   | *The Astrophysical Journal, Volume 803, Issue 1, p. 31*
+   | `https://arxiv.org/abs/1409.6388
+     <https://arxiv.org/abs/1409.6388>`_
+     
 """
 
 __author__ = 'C. A. Gomez Gonzalez, V. Christiaens, G. Ruane, R. Farkas'
@@ -44,7 +60,8 @@ from ..config.utils_conf import pool_map, iterable
 from ..stats import frame_basic_stats
 from ..var import (get_square, frame_center, get_annulus_segments,
                    fit_2dmoffat, fit_2dgaussian, fit_2dairydisk,
-                   fit_2d2gaussian, cube_filter_lowpass, cube_filter_highpass)
+                   fit_2d2gaussian, cube_filter_lowpass, cube_filter_highpass,
+                   frame_filter_highpass)
 from .cosmetics import cube_crop_frames, frame_crop
 
 
@@ -330,44 +347,47 @@ def frame_center_satspots(array, xy, subi_size=19, sigfactor=6, shift=False,
 
     Returns
     -------
-    array_rec
+    array_rec : 2d numpy array
         Shifted images. *Only returned if ``shift=True``.*
-    shifty, shiftx
+    shifty, shiftx : floats
         Shift Y,X to get to the true center.
+    ceny, cenx : floats
+        Center Y,X coordinates of the true center. *Only returned if 
+        ``shift=True``.*
+        
+    Note
+    ----
+    We are solving a linear system:
 
-    Notes
-    -----
-    linear system:
-
-    .. code-block: none
+    .. code-block:: python
 
         A1 * x + B1 * y = C1
         A2 * x + B2 * y = C2
 
     Cramer's rule - solution can be found in determinants:
 
-    .. code-block: none
+    .. code-block:: python
 
         x = Dx/D
         y = Dy/D
 
     where D is main determinant of the system:
 
-    .. code-block: none
+    .. code-block:: python
 
         A1 B1
         A2 B2
 
     and Dx and Dy can be found from matrices:
 
-    .. code-block: none
+    .. code-block:: python
 
         C1 B1
         C2 B2
 
     and
 
-    .. code-block: none
+    .. code-block:: python
 
         A1 C1
         A2 C2
@@ -376,7 +396,7 @@ def frame_center_satspots(array, xy, subi_size=19, sigfactor=6, shift=False,
 
     L stores our coefs A, B, C of the line equations.
 
-    .. code-block: none
+    .. code-block:: python
 
         For D: L1[0] L1[1]   for Dx: L1[2] L1[1]   for Dy: L1[0] L1[2]
                L2[0] L2[1]           L2[2] L2[1]           L2[0] L2[2]
@@ -615,13 +635,16 @@ def cube_recenter_satspots(array, xy, subi_size=19, sigfactor=6, plot=True,
         return array_rec
 
 
-def frame_center_radon(array, cropsize=None, hsize=0.4, step=0.01,
-                       mask_center=None, nproc=None, satspots_cfg=None, 
-                       theta_0=0, delta_theta=5, full_output=False, 
+def frame_center_radon(array, cropsize=None, hsize_ini=1., step_ini=0.1, 
+                       n_iter=5, tol=0.05, mask_center=None, nproc=None, 
+                       satspots_cfg=None, theta_0=0, delta_theta=5, 
+                       gauss_fit=True, hpf=True, filter_fwhm=8, imlib='vip-fft', 
+                       interpolation='lanczos4', full_output=False, 
                        verbose=True, plot=True, debug=False):
     """ Finding the center of a broadband (co-added) frame with speckles and
-    satellite spots elongated towards the star (center). We use the radon
-    transform implementation from scikit-image.
+    satellite spots elongated towards the star (center). We use the Radon
+    transform implementation from scikit-image, and follow the algorithm 
+    presented in [PUE15]_.
 
     Parameters
     ----------
@@ -631,11 +654,22 @@ def frame_center_radon(array, cropsize=None, hsize=0.4, step=0.01,
         Size in pixels of the cropped central area of the input array that will
         be used. It should be large enough to contain the bright elongated
         speckle or satellite spots.
-    hsize : float, optional
-        Size of the box for the grid search. The frame is shifted to each
-        direction from the center in a hsize length with a given step.
-    step : float, optional
-        The step of the coordinates change.
+    hsize_ini : float, optional
+        Size of the box for the grid search for first centering iteration. The 
+        frame is shifted to each direction from the center in a hsize length 
+        with a given step.
+    step_ini : float, optional
+        The step of the coordinates change in the first step. Note: should not 
+        be too fine for efficiency as it is automatically refined at each step.
+    n_iter : int, optional
+        Number of iterations for finer recentering. At each step, a finer 
+        step is considered based on the amplitude of the shifts found in the 
+        previous step. Iterations are particularly relevant when mask_center is 
+        not None (as the masked area will change from one iteration to the next).
+    tol : float, optional
+        Absolute tolerance on relative shift from one iteration to the next to
+        consider convergence. If the absolute value of the shift is found to be 
+        less than tol, the iterative algorithm is stopped.
     mask_center : None or int, optional
         If None the central area of the frame is kept. If int a centered zero
         mask will be applied to the frame. By default the center isn't masked.
@@ -646,9 +680,9 @@ def frame_center_radon(array, cropsize=None, hsize=0.4, step=0.01,
         If satellite spots are present, provide a string corresponding to the
         configuration of the satellite spots: as a cross ('x'), as a
         plus sign ('+') or 'custom' (provide theta_0). Leave to None if no 
-        satellite spots present. Usually the Radon transform centering works 
-        better if bright satellite spots are present.
-    theta_0: float, optional
+        satellite spots present. Note: setting satspots_cfg to non-None value
+        leads to varying performance depending on dataset.
+    theta_0: float between [0,90[, optional
         Azimuth of the first satellite spot. Only considered if satspots_cfg is
         set to 'custom'.
     delta_theta: float, optional
@@ -656,6 +690,18 @@ def frame_center_radon(array, cropsize=None, hsize=0.4, step=0.01,
         'x' pattern to calculate the Radon transform. E.g. if set to 5 for 'x'
         configuration, it will consider slices from 40 to 50 deg in each 
         quadrant.
+    hpf: bool, optional
+        Whether to high-pass filter the images
+    filter_fwhm: float, optional
+        In case of high-pass filtering, this is the FWHM of the low-pass filter
+        used for subtraction to the original image to get the high-pass 
+        filtered image (i.e. should be >~ 2 x FWHM).
+    imlib : str, optional
+        See the documentation of the ``vip_hci.preproc.frame_shift`` function.
+    interpolation : str, optional
+        See the documentation of the ``vip_hci.preproc.frame_shift`` function.
+    full_output: bool, optional
+        Whether to also return the cost map, and uncertainty on centering.
     verbose : bool optional
         Whether to print to stdout some messages and info.
     plot : bool, optional
@@ -665,158 +711,246 @@ def frame_center_radon(array, cropsize=None, hsize=0.4, step=0.01,
 
     Returns
     -------
-    [full_output=True] 2d np array
-        Radon cost function surface is returned if full_output set to True
-    optimy, optimx : float
+    optimy, optimx : floats
         Values of the Y, X coordinates of the center of the frame based on the
         radon optimization. (always returned)
-
-    Notes
-    -----
-    Based on Pueyo et al. 2014: http://arxiv.org/abs/1409.6388
+    dxy : float
+        [full_output=True] Uncertainty on center in pixels.
+    cost_bound : 2d numpy array
+        [full_output=True] Radon cost function surface.
 
     """
     from .cosmetics import frame_crop
-
+    
     if array.ndim != 2:
         raise TypeError('Input array is not a frame or 2d array')
 
     if verbose:
         start_time = time_ini()
-    frame = array.copy()
-    ori_cent_y, ori_cent_x = frame_center(frame)
-    if cropsize is not None:
-        if not cropsize % 2:
-            raise TypeError("If not None, cropsize should be odd integer")
-        frame = frame_crop(frame, cropsize, verbose=False)
-    listyx = np.linspace(start=-hsize, stop=hsize, num=int(2*hsize/step)+1,
-                         endpoint=True)
-    if not mask_center:
-        radint = 0
-    else:
-        if not isinstance(mask_center, int):
-            raise TypeError
-        radint = mask_center
+        
+    def _center_radon(array, cropsize=None, hsize=1., step=0.1, 
+                      mask_center=None, nproc=None, satspots_cfg=None, 
+                      theta_0=0, delta_theta=5, gauss_fit=False, 
+                      imlib='vip-fft', interpolation='lanczos4', 
+                      verbose=True, plot=True, debug=False):
 
-    coords = [(y, x) for y in listyx for x in listyx]
-    cent, _ = frame_center(frame)
-
-    frame = get_annulus_segments(frame, radint, cent-radint, mode="mask")[0]
-
-    if debug:
-        if satspots_cfg is not None:
-            samples = 10
-            if satspots_cfg == 'x':
-                theta = np.hstack((np.linspace(start=45-delta_theta, 
-                                               stop=45+delta_theta, num=samples,
-                                               endpoint=False),
-                                   np.linspace(start=135-delta_theta, 
-                                               stop=135+delta_theta, num=samples,
-                                               endpoint=False),
-                                   np.linspace(start=225-delta_theta, 
-                                               stop=225+delta_theta, num=samples,
-                                               endpoint=False),
-                                   np.linspace(start=315-delta_theta, 
-                                               stop=315+delta_theta, num=samples,
-                                               endpoint=False)))
-            elif satspots_cfg == '+':
-                theta = np.hstack((np.linspace(start=-delta_theta, 
-                                               stop=delta_theta, num=samples,
-                                               endpoint=False),
-                                   np.linspace(start=90-delta_theta, 
-                                               stop=90+delta_theta, num=samples,
-                                               endpoint=False),
-                                   np.linspace(start=180-delta_theta, 
-                                               stop=180+delta_theta, num=samples,
-                                               endpoint=False),
-                                   np.linspace(start=270-delta_theta, 
-                                               stop=270+delta_theta, num=samples,
-                                               endpoint=False)))
-            elif satspots_cfg == 'custom':
-                theta = np.hstack((np.linspace(start=theta_0-delta_theta, 
-                                               stop=theta_0+delta_theta, 
-                                               num=samples, endpoint=False),
-                                   np.linspace(start=theta_0+90-delta_theta, 
-                                               stop=theta_0+90+delta_theta, 
-                                               num=samples, endpoint=False),
-                                   np.linspace(start=theta_0+180-delta_theta, 
-                                               stop=theta_0+180+delta_theta, 
-                                               num=samples, endpoint=False),
-                                   np.linspace(start=theta_0+270-delta_theta, 
-                                               stop=theta_0+270+delta_theta, 
-                                               num=samples, endpoint=False)))                
-            else:
-                msg = "If not None, satspots_cfg can only be 'x' or '+'."
-                raise ValueError(msg)
-            sinogram = radon(frame, theta=theta, circle=True)
-            plot_frames((frame, sinogram))
-            print(np.sum(np.abs(sinogram[int(cent), :])))
+        frame = array.copy()
+        ori_cent_y, ori_cent_x = frame_center(frame)
+        if cropsize is not None:
+            if not cropsize % 2:
+                raise TypeError("If not None, cropsize should be odd integer")
+            frame = frame_crop(frame, cropsize, verbose=False)
+        listyx = np.linspace(start=-hsize, stop=hsize, num=int(2*hsize/step)+1,
+                             endpoint=True)
+        if not mask_center:
+            radint = 0
         else:
-            theta = np.linspace(start=0, stop=360, num=int(cent*2),
-                                endpoint=False)
-            sinogram = radon(frame, theta=theta, circle=True)
-            plot_frames((frame, sinogram))
-            print(np.sum(np.abs(sinogram[int(cent), :])))
-
-    if nproc is None:
-        nproc = cpu_count() // 2        # Hyper-threading doubles the # of cores
-
-    if nproc == 1:
-        costf = []
-        for coord in coords:
-            res = _radon_costf(frame, cent, radint, coord, satspots_cfg, 
-                               theta_0, delta_theta)
-            costf.append(res)
-        costf = np.array(costf)
-    elif nproc > 1:
-        res = pool_map(nproc, _radon_costf, frame, cent, radint,
-                       iterable(coords), satspots_cfg, theta_0, delta_theta)
-        costf = np.array(res)
+            if not isinstance(mask_center, int):
+                raise TypeError
+            radint = mask_center
+    
+        coords = [(y, x) for y in listyx for x in listyx]
+        cent, _ = frame_center(frame)
+    
+        frame = get_annulus_segments(frame, radint, cent-radint, mode="mask")[0]
+    
+        if debug:
+            if satspots_cfg is not None:
+                samples = 10
+                if satspots_cfg == 'x':
+                    theta = np.hstack((np.linspace(start=45-delta_theta, 
+                                                   stop=45+delta_theta, 
+                                                   num=samples,
+                                                   endpoint=False),
+                                       np.linspace(start=135-delta_theta, 
+                                                   stop=135+delta_theta, 
+                                                   num=samples,
+                                                   endpoint=False),
+                                       np.linspace(start=225-delta_theta, 
+                                                   stop=225+delta_theta, 
+                                                   num=samples,
+                                                   endpoint=False),
+                                       np.linspace(start=315-delta_theta, 
+                                                   stop=315+delta_theta, 
+                                                   num=samples,
+                                                   endpoint=False)))
+                elif satspots_cfg == '+':
+                    theta = np.hstack((np.linspace(start=-delta_theta, 
+                                                   stop=delta_theta, 
+                                                   num=samples,
+                                                   endpoint=False),
+                                       np.linspace(start=90-delta_theta, 
+                                                   stop=90+delta_theta, 
+                                                   num=samples,
+                                                   endpoint=False),
+                                       np.linspace(start=180-delta_theta, 
+                                                   stop=180+delta_theta, 
+                                                   num=samples,
+                                                   endpoint=False),
+                                       np.linspace(start=270-delta_theta, 
+                                                   stop=270+delta_theta, 
+                                                   num=samples,
+                                                   endpoint=False)))
+                elif satspots_cfg == 'custom':
+                    theta = np.hstack((np.linspace(start=90-theta_0-delta_theta, 
+                                                   stop=90-theta_0+delta_theta, 
+                                                   num=samples, endpoint=False),
+                                       np.linspace(start=180-theta_0-delta_theta, 
+                                                   stop=180-theta_0+delta_theta, 
+                                                   num=samples, endpoint=False),
+                                       np.linspace(start=270-theta_0-delta_theta, 
+                                                   stop=270-theta_0+delta_theta, 
+                                                   num=samples, endpoint=False),
+                                       np.linspace(start=360-theta_0-delta_theta, 
+                                                   stop=360-theta_0+delta_theta, 
+                                                   num=samples, endpoint=False)))                
+                else:
+                    msg = "If not None, satspots_cfg can only be 'x' or '+'."
+                    raise ValueError(msg)
+                sinogram = radon(frame, theta=theta, circle=True)
+                plot_frames((frame, sinogram))
+                print(np.sum(np.abs(sinogram[int(cent), :])))
+            else:
+                theta = np.linspace(start=0, stop=360, num=int(cent*2),
+                                    endpoint=False)
+                sinogram = radon(frame, theta=theta, circle=True)
+                plot_frames((frame, sinogram))
+                print(np.sum(np.abs(sinogram[int(cent), :])))
+    
+        if nproc is None:
+            nproc = cpu_count() // 2        # Hyper-threading doubles the # of cores
+    
+        if nproc == 1:
+            costf = []
+            for coord in coords:
+                res = _radon_costf(frame, cent, radint, coord, satspots_cfg, 
+                                   theta_0, delta_theta, imlib, interpolation)
+                costf.append(res)
+            costf = np.array(costf)
+        elif nproc > 1:
+            res = pool_map(nproc, _radon_costf, frame, cent, radint, 
+                           iterable(coords), satspots_cfg, theta_0, delta_theta, 
+                           imlib, interpolation)
+            costf = np.array(res)
+    
+        if verbose:
+            msg = 'Done {} radon transform calls distributed in {} processes'
+            print(msg.format(len(coords), nproc))
+    
+        cost_bound = costf.reshape(listyx.shape[0], listyx.shape[0])
+        if plot:
+            plt.contour(cost_bound, cmap='CMRmap', origin='lower')
+            plt.imshow(cost_bound, cmap='CMRmap', origin='lower',
+                       interpolation='nearest')
+            plt.colorbar()
+            plt.grid('off')
+            plt.show()
+    
+        if gauss_fit or full_output:
+            # fit a 2d gaussian to the surface
+            fit_res = fit_2dgaussian(cost_bound-np.amin(cost_bound), crop=False, 
+                                     threshold=False, sigfactor=1, debug=debug, 
+                                     full_output=True)
+            ## optimal shift -> optimal position
+            opt_yind = float(fit_res['centroid_y'])
+            opt_xind = float(fit_res['centroid_x'])
+            opt_yshift = -hsize + opt_yind*step
+            opt_xshift = -hsize + opt_xind*step
+            optimy = ori_cent_y - opt_yshift
+            optimx = ori_cent_x - opt_xshift
+            
+            ## find uncertainty on centering
+            unc_y = float(fit_res['fwhm_y'])*step
+            unc_x = float(fit_res['fwhm_x'])*step
+            dyx = (unc_y, unc_x) #np.sqrt(unc_y**2 + unc_x**2)
+    
+        # Replace the position found by Gaussian fit
+        if not gauss_fit:
+            # OLD CODE:
+            # argm = np.argmax(costf) # index of 1st max in 1d cost function 'surface'
+            # optimy, optimx = coords[argm]
+    
+            # maxima in the 2d cost function surface
+            num_max = np.where(cost_bound == cost_bound.max())[0].shape[0]
+            ind_maximay, ind_maximax = np.where(cost_bound == cost_bound.max())
+            argmy = ind_maximay[int(np.ceil(num_max/2)) - 1]
+            argmx = ind_maximax[int(np.ceil(num_max/2)) - 1]
+            y_grid = np.array(coords)[:, 0].reshape(listyx.shape[0], 
+                                                    listyx.shape[0])
+            x_grid = np.array(coords)[:, 1].reshape(listyx.shape[0], 
+                                                    listyx.shape[0])
+            optimy = ori_cent_y-y_grid[argmy, 0]  # subtract optimal shift
+            optimx = ori_cent_x-x_grid[0, argmx]  # subtract optimal shift
+    
+        if verbose:
+            print('Cost function max: {}'.format(costf.max()))
+            #print('Cost function # maxima: {}'.format(num_max))
+            msg = 'Finished grid search radon optimization. dy={:.3f}, dx={:.3f}'
+            print(msg.format(opt_yshift, opt_xshift))
+            timing(start_time)
+    
+        return optimy, optimx, opt_yshift, opt_xshift, dyx, cost_bound
+    
+    # high-pass filtering if requested
+    if hpf:
+        array = frame_filter_highpass(array, mode='gauss-subt', 
+                                      fwhm_size=filter_fwhm)
+    
+    ori_cent_y, ori_cent_x = frame_center(array)
+    hsize = hsize_ini
+    step = step_ini
+    opt_yshift = 0
+    opt_xshift = 0
+    for i in range(n_iter):
+        if verbose:
+            print("*** Iteration {}/{} ***".format(i+1, n_iter))
+        res = _center_radon(array, cropsize=cropsize, hsize=hsize, step=step, 
+                            mask_center=mask_center, nproc=nproc, 
+                            satspots_cfg=satspots_cfg, theta_0=theta_0, 
+                            delta_theta=delta_theta, gauss_fit=gauss_fit, 
+                            imlib=imlib, interpolation=interpolation, 
+                            verbose=verbose, plot=plot, debug=debug)
+        _, _, y_shift, x_shift, dyx, cost_bound = res
+        array = frame_shift(array, y_shift, x_shift, imlib=imlib, 
+                            interpolation=interpolation)
+        opt_yshift += y_shift
+        opt_xshift += x_shift
+        
+        abs_shift = np.sqrt(y_shift**2 + x_shift**2)
+        if abs_shift < tol:
+            if i == 0:
+                msg = "Null shifts found at first iteration for step = {}. Try"
+                msg += " with a finer step."
+                raise ValueError(msg.format(step))
+            else:
+                msg = "Convergence found after {} iterations (final step = {})."
+            print(msg.format(i+1, step))
+            break
+        # refine box
+        max_sh = np.amax(np.abs(np.array([y_shift,x_shift])))
+        hsize = 2*max_sh
+        step = hsize/10.
 
+    optimy = ori_cent_y-opt_yshift
+    optimx = ori_cent_x-opt_xshift
+        
     if verbose:
-        msg = 'Done {} radon transform calls distributed in {} processes'
-        print(msg.format(len(coords), nproc))
-
-    cost_bound = costf.reshape(listyx.shape[0], listyx.shape[0])
-    if plot:
-        plt.contour(cost_bound, cmap='CMRmap', origin='lower')
-        plt.imshow(cost_bound, cmap='CMRmap', origin='lower',
-                   interpolation='nearest')
-        plt.colorbar()
-        plt.grid('off')
-        plt.show()
-
-    # argm = np.argmax(costf) # index of 1st max in 1d cost function 'surface'
-    # optimy, optimx = coords[argm]
-
-    # maxima in the 2d cost function surface
-    num_max = np.where(cost_bound == cost_bound.max())[0].shape[0]
-    ind_maximay, ind_maximax = np.where(cost_bound == cost_bound.max())
-    argmy = ind_maximay[int(np.ceil(num_max/2)) - 1]
-    argmx = ind_maximax[int(np.ceil(num_max/2)) - 1]
-    y_grid = np.array(coords)[:, 0].reshape(listyx.shape[0], listyx.shape[0])
-    x_grid = np.array(coords)[:, 1].reshape(listyx.shape[0], listyx.shape[0])
-    optimy = ori_cent_y+y_grid[argmy, 0]  # +(ori_cent-cent)/2
-    optimx = ori_cent_x+x_grid[0, argmx]  # +(ori_cent-cent)/2
-
-    if verbose:
-        print('Cost function max: {}'.format(costf.max()))
-        print('Cost function # maxima: {}'.format(num_max))
-        msg = 'Finished grid search radon optimization. Y={:.5f}, X={:.5f}'
-        print(msg.format(optimy, optimx))
-        timing(start_time)
+        print("Star (x,y) location: {:.2f}, {:.2f}".format(optimx, optimy))
+        print("Final cumulative (x,y) shifts: {:.2f}, {:.2f}".format(opt_xshift, 
+                                                                     opt_yshift))
 
     if full_output:
-        return cost_bound, optimy, optimx
+        return optimy, optimx, dyx, cost_bound
     else:
         return optimy, optimx
-
+        
 
 def _radon_costf(frame, cent, radint, coords, satspots_cfg=None, theta_0=0, 
-                 delta_theta=5):
+                 delta_theta=5, imlib='vip-fft', interpolation='lanczos4'):
     """ Radon cost function used in frame_center_radon().
     """
-    frame_shifted = frame_shift(frame, coords[0], coords[1])
+    frame_shifted = frame_shift(frame, coords[0], coords[1], imlib=imlib,
+                                interpolation=interpolation)
     frame_shifted_ann = get_annulus_segments(frame_shifted, radint,
                                              cent-radint, mode="mask")[0]
 
@@ -873,7 +1007,7 @@ def cube_recenter_radon(array, full_output=False, verbose=True, imlib='vip-fft',
                         interpolation='lanczos4', border_mode='reflect',
                         **kwargs):
     """ Recenters a cube looping through its frames and calling the
-    ``frame_center_radon`` function.
+    ``frame_center_radon`` function, as in [PUE15]_.
 
     Parameters
     ----------
@@ -896,9 +1030,9 @@ def cube_recenter_radon(array, full_output=False, verbose=True, imlib='vip-fft',
         reflecting about the center of the last pixel. With 'wrap', the input is
         extended by wrapping around to the opposite edge. Default is 'reflect'.
     kwargs:
-        Additional optional parameters from vip_hci.preproc.frame_center_radon
+        Additional optional parameters for ``vip_hci.preproc.frame_center_radon``
         function, such as cropsize, hsize, step, satspots_cfg, mask_center,
-        nproc or debug.
+        hpf, filter_fwhm, nproc or debug.
 
 
     Returns
@@ -907,6 +1041,8 @@ def cube_recenter_radon(array, full_output=False, verbose=True, imlib='vip-fft',
         Recentered cube.
     y, x : 1d arrays of floats
         [full_output] Shifts in y and x.
+    dyx: 1d array of floats
+        [full_output] Array of uncertainty on center in pixels.
 
     """
     check_array(array, dim=3)
@@ -917,13 +1053,18 @@ def cube_recenter_radon(array, full_output=False, verbose=True, imlib='vip-fft',
     n_frames = array.shape[0]
     x = np.zeros((n_frames))
     y = np.zeros((n_frames))
+    dyx = np.zeros((n_frames,2))
     cy, cx = frame_center(array[0])
     array_rec = array.copy()
 
     for i in Progressbar(range(n_frames), desc="Recentering frames...", 
                          verbose=verbose):
-        y[i], x[i] = frame_center_radon(array[i], verbose=False, plot=False,
-                                        **kwargs)
+        res = frame_center_radon(array[i], verbose=False, plot=False, 
+                                 imlib=imlib, interpolation=interpolation,
+                                 full_output=True, **kwargs)
+        y[i] = res[0]
+        x[i] = res[1]
+        dyx[i] = res[2]
         array_rec[i] = frame_shift(array[i], cy-y[i], cx-x[i], imlib=imlib,
                                    interpolation=interpolation,
                                    border_mode=border_mode)
@@ -932,7 +1073,7 @@ def cube_recenter_radon(array, full_output=False, verbose=True, imlib='vip-fft',
         timing(start_time)
 
     if full_output:
-        return array_rec, cy-y, cx-x
+        return array_rec, cy-y, cx-x, dyx
     else:
         return array_rec
 
@@ -943,9 +1084,9 @@ def cube_recenter_dft_upsampling(array, center_fr1=None, negative=False,
                                  mask=None, border_mode='reflect',
                                  full_output=False, verbose=True, nproc=1,
                                  save_shifts=False, debug=False, plot=True):
-    """ Recenters a cube of frames using the DFT upsampling method as
-    proposed in Guizar et al. 2008 and implemented in the
-    ``register_translation`` function from scikit-image.
+    """ Recenters a cube of frames using the DFT upsampling method as proposed 
+    in [GUI08]_ and implemented in the ``register_translation`` function from 
+    scikit-image.
 
     The algorithm (DFT upsampling) obtains an initial estimate of the
     cross-correlation peak by an FFT and then refines the shift estimation by
@@ -1011,13 +1152,12 @@ def cube_recenter_dft_upsampling(array, center_fr1=None, negative=False,
     x : numpy ndarray
         [full_output=True] 1d array with the shifts in x.
 
-    Notes
-    -----
-    Using the implementation from scikit-image of the algorithm described in
-    Guizar-Sicairos et al. "Efficient subpixel image registration algorithms,"
-    Opt. Lett. 33, 156-158 (2008). This algorithm registers two images (2-D
-    rigid translation) within a fraction of a pixel specified by the user.
-    Instead of computing a zero-padded FFT (fast Fourier transform), this code
+    Note
+    ----
+    This function uses the implementation from scikit-image of the algorithm 
+    described in [GUI08]_. This algorithm registers two images (2-D rigid 
+    translation) within a fraction of a pixel specified by the user. Instead of 
+    computing a zero-padded FFT (fast Fourier transform), this code
     uses selective upsampling by a matrix-multiply DFT (discrete FT) to
     dramatically reduce computation time and memory without sacrificing
     accuracy. With this procedure all the image points are used to compute the
@@ -1190,7 +1330,7 @@ def cube_recenter_2dfit(array, xy=None, fwhm=4, subi_size=5, model='gauss',
         FWHM size in pixels, either one value (float) that will be the same for
         the whole cube, or an array of floats with the same dimension as the
         0th dim of array, containing the fwhm for each channel (e.g. in the case
-        of an ifs cube, where the fwhm varies with wavelength)
+        of an IFS cube, where the FWHM varies with wavelength).
     subi_size : int, optional
         Size of the square subimage sides in pixels.
     model : str, optional
@@ -1218,11 +1358,14 @@ def cube_recenter_2dfit(array, xy=None, fwhm=4, subi_size=5, model='gauss',
         guess parameters for the double gaussian. E.g.:
         params_2g = {'fwhm_neg': 3.5, 'fwhm_pos': (3.5,4.2), 'theta_neg': 48.,
         'theta_pos':145., 'neg_amp': 0.5}
-        fwhm_neg: float or tuple with fwhm of neg gaussian
-        fwhm_pos: can be a tuple for x and y axes of pos gaussian (replaces fwhm)
-        theta_neg: trigonometric angle of the x axis of the neg gaussian (deg)
-        theta_pos: trigonometric angle of the x axis of the pos gaussian (deg)
-        neg_amp: amplitude of the neg gaussian wrt the amp of the positive one
+        
+        - fwhm_neg: float or tuple with fwhm of neg gaussian
+        - fwhm_pos: can be a tuple for x and y axes of pos gaussian (replaces
+          fwhm)
+        - theta_neg: trigonometric angle of the x axis of the neg gaussian (deg)
+        - theta_pos: trigonometric angle of the x axis of the pos gaussian (deg)
+        - neg_amp: amplitude of the neg gaussian wrt the amp of the positive one
+        
         Note: it is always recommended to provide theta_pos and theta_neg for a
         better fit.
     threshold : bool, optional
@@ -1502,7 +1645,6 @@ def _centroid_2d2g_frame(cube, frnum, size, pos_y, pos_x, debug=False, fwhm=4,
     return y_i, x_i
 
 
-# TODO: make parameter names match the API
 def cube_recenter_via_speckles(cube_sci, cube_ref=None, alignment_iter=5,
                                gammaval=1, min_spat_freq=0.5, max_spat_freq=3,
                                fwhm=4, debug=False, recenter_median=False,
@@ -1570,24 +1712,22 @@ def cube_recenter_via_speckles(cube_sci, cube_ref=None, alignment_iter=5,
 
     Returns
     -------
-    if full_output is False, returns:
-        cube_reg_sci: Registered science cube (numpy 3d ndarray)
-
-        If cube_ref is not None, also returns:
-
-        cube_reg_ref: Ref. cube registered to science frames (np 3d ndarray)
-
-    If full_output is True, returns in addition to the above:
-        cube_sci_lpf: Low+high-pass filtered science cube (np 3d ndarray)
-        cube_stret: Cube with stretched values used for cross-corr (np 3d ndarray)
-        cum_x_shifts_sci: Vector of x shifts for science frames (np 1d array)
-        cum_y_shifts_sci: Vector of y shifts for science frames (np 1d array)
-
-        And if cube_ref is not None, also returns:
-        cum_x_shifts_ref: Vector of x shifts for ref. frames.
-        cum_y_shifts_ref: Vector of y shifts for ref. frames.
-
-
+    cube_reg_sci : numpy 3d ndarray
+        Registered science cube 
+    cube_reg_ref : numpy 3d ndarray
+        [cube_ref!=None] Cube registered to science frames
+    cube_sci_lpf : numpy 3d ndarray
+        [full_output=True] Low+high-pass filtered science cube 
+    cube_stret : numpy 3d ndarray
+        [full_output=True] cube_stret with stretched values used for cross-corr
+    cum_x_shifts_sci: numpy 1d array
+        [full_output=True] Vector of x shifts for science frames 
+    cum_y_shifts_sci: numpy 1d array
+        [full_output=True] Vector of x shifts for science frames 
+    cum_x_shifts_ref: numpy 1d array
+        [full_output=True & cube_ref!=None] Vector of x shifts for ref frames 
+    cum_y_shifts_ref: numpy 1d array
+        [full_output=True & cube_ref!=None] Vector of y shifts for ref frames
     """
     n, y, x = cube_sci.shape
     check_array(cube_sci, dim=3)
