@@ -9,10 +9,33 @@ Full-frame PCA algorithm for ADI, (ADI+)RDI and (ADI+)mSDI (IFS data) cubes:
   is the number of frames and P the number of pixels in a frame is created. Then
   PCA is done through eigen-decomposition of the covariance matrix (~$DD^T$) or
   the SVD of the data matrix. SVD can be calculated using different libraries
-  including the fast randomized SVD (Halko et al. 2009).
+  including the fast randomized SVD.
 
 - *Full-frame incremental PCA* for big (larger than available memory) cubes.
 
+.. [AMA12]
+   | Amara & Quanz 2012
+   | **PYNPOINT: an image processing package for finding exoplanets**
+   | *MNRAS, Volume 427, Issue 1, pp. 948-955*
+   | `https://arxiv.org/abs/1207.6637
+     <https://arxiv.org/abs/1207.6637>`_
+     
+.. [CHR19]
+   | Christiaens et al. 2019
+   | **Separating extended disc features from the protoplanet in PDS 70 using 
+     VLT/SINFONI**
+   | *MNRAS, Volume 486, Issue 4, pp. 5819-5837*
+   | `https://arxiv.org/abs/1905.01860
+     <https://arxiv.org/abs/1905.01860>`_
+     
+.. [HAL09]
+   | Halko et al. 2009
+   | **Finding structure with randomness: Probabilistic algorithms for 
+     constructing approximate matrix decompositions**
+   | *arXiv e-prints*
+   | `https://arxiv.org/abs/0909.4061
+     <https://arxiv.org/abs/0909.4061>`_
+
 """
 
 __author__ = 'Carlos Alberto Gomez Gonzalez, Valentin Christiaens'
@@ -49,18 +72,17 @@ def pca(cube, angle_list, cube_ref=None, scale_list=None, ncomp=1,
     ADI: the target ``cube`` itself is used to learn the PCs and to obtain a
     low-rank approximation model PSF (star + speckles). Both `cube_ref`` and
     ``scale_list`` must be None. The full-frame ADI-PCA implementation is based
-    on Soummer et al. 2012 (http://arxiv.org/abs/1207.4197) and Amara & Quanz
-    2012 (http://arxiv.org/abs/1207.6637). If ``batch`` is provided then the
-    cube if processed with incremental PCA as described in Gomez Gonzalez et al.
-    2017 (https://arxiv.org/abs/1705.06184).
+    on [AMA12]_ and [SOU12]_. If ``batch`` is provided then the cube is processed 
+    with incremental PCA as described in [GOM17]_.
 
     (ADI+)RDI: if a reference cube is provided (``cube_ref``), its PCs are used
     to reconstruct the target frames to obtain the model PSF (star + speckles).
 
     (ADI+)mSDI (IFS data): if a scaling vector is provided (``scale_list``) and
-    the cube is a 4d array [# channels, # adi-frames, Y, X], its assumed it
+    the cube is a 4d array [# channels, # adi-frames, Y, X], it's assumed it
     contains several multi-spectral frames acquired in pupil-stabilized mode.
-    A single or two stages PCA can be performed, depending on ``adimsdi``.
+    A single or two stages PCA can be performed, depending on ``adimsdi``, as 
+    explained in [CHR19]_.
 
     Parameters
     ----------
@@ -147,7 +169,7 @@ def pca(cube, angle_list, cube_ref=None, scale_list=None, ncomp=1,
           eigendecomposition of the covariance M.M' (computation on CPU).
 
         * ``randsvd``: uses the randomized_svd algorithm implemented in
-          Sklearn (computation on CPU).
+          Sklearn (computation on CPU), proposed in [HAL09]_.
 
         * ``cupy``: uses the Cupy library for GPU computation of the SVD as in
           the LAPACK version. `
@@ -664,6 +686,8 @@ def _adi_pca(cube, angle_list, ncomp, batch, source_xy, delta_rot, fwhm,
                                             nproc=nproc, imlib=imlib,
                                             interpolation=interpolation,
                                             **rot_options)
+            if mask_center_px:
+                residuals_cube_ = mask_circle(residuals_cube_, mask_center_px)
             frame = cube_collapse(residuals_cube_, mode=collapse, w=weights)
             if verbose:
                 print('Done de-rotating and combining')
@@ -998,8 +1022,8 @@ def _adi_rdi_pca(cube, cube_ref, angle_list, ncomp, scaling, mask_center_px,
     return pcs, recon, residuals_cube, residuals_cube_, frame
 
 
-def _project_subtract(cube, cube_ref, ncomp, scaling, mask_center_px,
-                      svd_mode, verbose, full_output, indices=None, frame=None,
+def _project_subtract(cube, cube_ref, ncomp, scaling, mask_center_px, svd_mode, 
+                      verbose, full_output, indices=None, frame=None,
                       cube_sig=None):
     """
     PCA projection and model PSF subtraction. Used as a helping function by
