@@ -3,6 +3,15 @@
 """
 Module with local/smart PCA (annulus or patch-wise in a multi-processing
 fashion) model PSF subtraction for ADI, ADI+SDI (IFS) and ADI+RDI datasets.
+
+.. [ABS13]
+   | Absil et al. 2013
+   | **Searching for companions down to 2 AU from beta Pictoris using the 
+     L'-band AGPM coronagraph on VLT/NACO**
+   | *Astronomy & Astrophysics, Volume 559, Issue 1, p. 12*
+   | `https://arxiv.org/abs/1311.4298
+     <https://arxiv.org/abs/1311.4298>`_
+
 """
 
 __author__ = 'Carlos Alberto Gomez Gonzalez, Valentin Christiaens'
@@ -27,8 +36,8 @@ def pca_annular(cube, angle_list, cube_ref=None, scale_list=None, radius_int=0,
                 delta_sep=(0.1, 1), ncomp=1, svd_mode='lapack', nproc=1,
                 min_frames_lib=2, max_frames_lib=200, tol=1e-1, scaling=None,
                 imlib='vip-fft', interpolation='lanczos4', collapse='median',
-                collapse_ifs='mean', ifs_collapse_range='all',
-                full_output=False, verbose=True, weights=None, cube_sig=None,
+                collapse_ifs='mean', ifs_collapse_range='all', theta_init=0, 
+                weights=None, cube_sig=None, full_output=False, verbose=True, 
                 **rot_options):
     """ PCA model PSF subtraction for ADI, ADI+RDI or ADI+mSDI (IFS) data. The
     PCA model is computed locally in each annulus (or annular sectors according
@@ -40,6 +49,10 @@ def pca_annular(cube, angle_list, cube_ref=None, scale_list=None, radius_int=0,
     library/cube, forcing pixel-wise temporal standardization. The number of
     principal components can be automatically adjusted by the algorithm by
     minimizing the residuals inside each patch/region.
+    
+    References: [AMA12]_ for PCA-ADI; [ABS13]_ for PCA-ADI in concentric annuli 
+    considering a parallactic angle threshold; [CHR19]_ for PCA-ASDI and 
+    PCA-SADI in one or two steps.
 
     Parameters
     ----------
@@ -105,36 +118,36 @@ def pca_annular(cube, angle_list, cube_ref=None, scale_list=None, radius_int=0,
         'randcupy', 'pytorch', 'eigenpytorch', 'randpytorch'}, str optional
         Switch for the SVD method/library to be used.
 
-        ``lapack``: uses the LAPACK linear algebra library through Numpy
-        and it is the most conventional way of computing the SVD
-        (deterministic result computed on CPU).
+        * ``lapack``: uses the LAPACK linear algebra library through Numpy
+          and it is the most conventional way of computing the SVD
+          (deterministic result computed on CPU).
 
-        ``arpack``: uses the ARPACK Fortran libraries accessible through
-        Scipy (computation on CPU).
+        * ``arpack``: uses the ARPACK Fortran libraries accessible through
+          Scipy (computation on CPU).
 
-        ``eigen``: computes the singular vectors through the
-        eigendecomposition of the covariance M.M' (computation on CPU).
+        * ``eigen``: computes the singular vectors through the
+          eigendecomposition of the covariance M.M' (computation on CPU).
 
-        ``randsvd``: uses the randomized_svd algorithm implemented in
-        Sklearn (computation on CPU).
+        * ``randsvd``: uses the randomized_svd algorithm implemented in
+          Sklearn (computation on CPU), proposed in [HAL09]_.
 
-        ``cupy``: uses the Cupy library for GPU computation of the SVD as in
-        the LAPACK version. `
+        * ``cupy``: uses the Cupy library for GPU computation of the SVD as in
+          the LAPACK version. `
 
-        `eigencupy``: offers the same method as with the ``eigen`` option
-        but on GPU (through Cupy).
+        * ``eigencupy``: offers the same method as with the ``eigen`` option
+          but on GPU (through Cupy).
 
-        ``randcupy``: is an adaptation of the randomized_svd algorithm,
-        where all the computations are done on a GPU (through Cupy). `
+        * ``randcupy``: is an adaptation of the randomized_svd algorithm,
+          where all the computations are done on a GPU (through Cupy). `
 
-        `pytorch``: uses the Pytorch library for GPU computation of the SVD.
+        * ``pytorch``: uses the Pytorch library for GPU computation of the SVD.
 
-        ``eigenpytorch``: offers the same method as with the ``eigen``
-        option but on GPU (through Pytorch).
+        * ``eigenpytorch``: offers the same method as with the ``eigen``
+          option but on GPU (through Pytorch).
 
-        ``randpytorch``: is an adaptation of the randomized_svd algorithm,
-        where all the linear algebra computations are done on a GPU
-        (through Pytorch).
+        * ``randpytorch``: is an adaptation of the randomized_svd algorithm,
+          where all the linear algebra computations are done on a GPU
+          (through Pytorch).
 
     nproc : None or int, optional
         Number of processes for parallel computing. If None the number of
@@ -152,15 +165,15 @@ def pca_annular(cube, angle_list, cube_ref=None, scale_list=None, radius_int=0,
         Pixel-wise scaling mode using ``sklearn.preprocessing.scale``
         function. If set to None, the input matrix is left untouched. Otherwise:
 
-        ``temp-mean``: temporal px-wise mean is subtracted.
+        * ``temp-mean``: temporal px-wise mean is subtracted.
 
-        ``spat-mean``: spatial mean is subtracted.
+        * ``spat-mean``: spatial mean is subtracted.
 
-        ``temp-standard``: temporal mean centering plus scaling pixel values
-        to unit variance. HIGHLY RECOMMENDED FOR ASDI AND RDI CASES.
+        * ``temp-standard``: temporal mean centering plus scaling pixel values
+          to unit variance. HIGHLY RECOMMENDED FOR ASDI AND RDI CASES!
 
-        ``spat-standard``: spatial mean centering plus scaling pixel values
-        to unit variance.
+        * ``spat-standard``: spatial mean centering plus scaling pixel values
+          to unit variance.
 
     imlib : str, optional
         See the documentation of the ``vip_hci.preproc.frame_rotate`` function.
@@ -178,8 +191,10 @@ def pca_annular(cube, angle_list, cube_ref=None, scale_list=None, radius_int=0,
         Whether to return the final median combined image only or with other
         intermediate arrays.
     verbose : bool, optional
-        If True prints to stdout intermediate info. If set to 2, the number of
-        frames in library and number of PCs are printed for each annular quadrant.
+        If True prints to stdout intermediate info.
+    theta_init : int
+        Initial azimuth [degrees] of the first segment, counting from the
+        positive x-axis counterclockwise (irrelevant if n_segments=1).
     weights: 1d numpy array or list, optional
         Weights to be applied for a weighted mean. Need to be provided if
         collapse mode is 'wmean'.
@@ -193,16 +208,14 @@ def pca_annular(cube, angle_list, cube_ref=None, scale_list=None, radius_int=0,
 
     Returns
     -------
-    - If full_output is False:
     frame : numpy ndarray, 2d
-        Median combination of the de-rotated cube.
-    - If full_output is True:
+        [full_output=False] Median combination of the de-rotated cube.
     array_out : numpy ndarray, 3d or 4d
-        Cube of residuals.
+        [full_output=True] Cube of residuals.
     array_der : numpy ndarray, 3d or 4d
-        Cube residuals after de-rotation.
+        [full_output=True] Cube residuals after de-rotation.
     frame : numpy ndarray, 2d
-        Median combination of the de-rotated cube.
+        [full_output=True] Median combination of the de-rotated cube.
     """
     if verbose:
         global start_time
@@ -214,7 +227,7 @@ def pca_annular(cube, angle_list, cube_ref=None, scale_list=None, radius_int=0,
                            n_segments, delta_rot, ncomp, svd_mode, nproc,
                            min_frames_lib, max_frames_lib, tol, scaling, imlib,
                            interpolation, collapse, True, verbose, cube_ref,
-                           weights, cube_sig, **rot_options)
+                           theta_init, weights, cube_sig, **rot_options)
 
         cube_out, cube_der, frame = res
         if full_output:
@@ -300,7 +313,8 @@ def pca_annular(cube, angle_list, cube_ref=None, scale_list=None, radius_int=0,
         res = pool_map(nproc, _pca_sdi_fr, iterable(range(n)), scale_list,
                        radius_int, fwhm, asize, n_segments, delta_sep, ncomp,
                        svd_mode, tol, scaling, imlib, interpolation,
-                       collapse_ifs, ifs_collapse_range, verbose=verbose)
+                       collapse_ifs, ifs_collapse_range, theta_init, 
+                       verbose=verbose)
         residuals_cube_channels = np.array(res)
 
         # Exploiting rotational variability
@@ -327,8 +341,8 @@ def pca_annular(cube, angle_list, cube_ref=None, scale_list=None, radius_int=0,
                                fwhm, asize, n_segments, delta_rot, ncomp2,
                                svd_mode, nproc, min_frames_lib, max_frames_lib,
                                tol, scaling, imlib, interpolation, collapse,
-                               full_output, verbose, None, weights, cube_sig,
-                               **rot_options)
+                               full_output, verbose, None, theta_init, weights, 
+                               cube_sig, **rot_options)
             if full_output:
                 cube_out, cube_der, frame = res
             else:
@@ -350,7 +364,7 @@ def pca_annular(cube, angle_list, cube_ref=None, scale_list=None, radius_int=0,
 
 def _pca_sdi_fr(fr, scal, radius_int, fwhm, asize, n_segments, delta_sep, ncomp,
                 svd_mode, tol, scaling, imlib, interpolation, collapse,
-                ifs_collapse_range):
+                ifs_collapse_range, theta_init):
     """ Optimized PCA subtraction on a multi-spectral frame (IFS data).
     """
     z, n, y_in, x_in = ARRAY.shape
@@ -391,7 +405,7 @@ def _pca_sdi_fr(fr, scal, radius_int, fwhm, asize, n_segments, delta_sep, ncomp,
         ann_center = inner_radius + (asize / 2)
 
         indices = get_annulus_segments(multispec_fr[0], inner_radius, asize,
-                                       n_segments[ann])
+                                       n_segments[ann], theta_init)
         # Library matrix is created for each segment and scaled if needed
         for seg in range(n_segments[ann]):
             yy = indices[seg][0]
@@ -431,8 +445,8 @@ def _pca_adi_rdi(cube, angle_list, radius_int=0, fwhm=4, asize=2, n_segments=1,
                  delta_rot=1, ncomp=1, svd_mode='lapack', nproc=None,
                  min_frames_lib=2, max_frames_lib=200, tol=1e-1, scaling=None,
                  imlib='vip-fft', interpolation='lanczos4', collapse='median',
-                 full_output=False, verbose=1, cube_ref=None, weights=None,
-                 cube_sig=None, **rot_options):
+                 full_output=False, verbose=1, cube_ref=None, theta_init=0, 
+                 weights=None, cube_sig=None, **rot_options):
     """ PCA exploiting angular variability (ADI fashion).
     """
     array = cube
@@ -490,7 +504,7 @@ def _pca_adi_rdi(cube, angle_list, radius_int=0, fwhm=4, asize=2, n_segments=1,
                                      n_segments_ann, verbose, True)
         pa_thr, inner_radius, ann_center = res_ann_par
         indices = get_annulus_segments(array[0], inner_radius, asize,
-                                       n_segments_ann)
+                                       n_segments_ann, theta_init)
         # Library matrix is created for each segment and scaled if needed
         for j in range(n_segments_ann):
             yy = indices[j][0]
@@ -577,6 +591,9 @@ def do_pca_patch(matrix, frame, angle_list, fwhm, pa_threshold, ann_center,
 
         if data_ref.shape[0] < min_frames_lib and matrix_ref is None:
             raise RuntimeError(msg.format(len(indices_left), min_frames_lib))
+    else:
+        data_ref = None
+
     if matrix_ref is not None:
         #data_ref = None
         # if matrix_ref is not None:
@@ -591,6 +608,13 @@ def do_pca_patch(matrix, frame, angle_list, fwhm, pa_threshold, ann_center,
         else:
             data_ref = matrix
 
+    if matrix_ref is not None and matrix_sig_segm is None:
+        # Stacking the ref and the target (pa thresh) libraries
+        if data_ref is not None:
+            data_ref = np.vstack((matrix_ref, data_ref))
+        else:
+            data_ref = matrix_ref
+
     curr_frame = matrix[frame]  # current frame
     if matrix_sig_segm is not None:
         curr_frame_emp = matrix[frame]-matrix_sig_segm[frame]
