@@ -71,51 +71,51 @@ def pca_grid(cube, angle_list, fwhm=None, range_pcs=None, source_xy=None,
         'randcupy', 'pytorch', 'eigenpytorch', 'randpytorch'}, str optional
         Switch for the SVD method/library to be used.
 
-        ``lapack``: uses the LAPACK linear algebra library through Numpy
-        and it is the most conventional way of computing the SVD
-        (deterministic result computed on CPU).
+        * ``lapack``: uses the LAPACK linear algebra library through Numpy
+          and it is the most conventional way of computing the SVD
+          (deterministic result computed on CPU).
 
-        ``arpack``: uses the ARPACK Fortran libraries accessible through
-        Scipy (computation on CPU).
+        * ``arpack``: uses the ARPACK Fortran libraries accessible through
+          Scipy (computation on CPU).
 
-        ``eigen``: computes the singular vectors through the
-        eigendecomposition of the covariance M.M' (computation on CPU).
+        * ``eigen``: computes the singular vectors through the
+          eigendecomposition of the covariance M.M' (computation on CPU).
 
-        ``randsvd``: uses the randomized_svd algorithm implemented in
-        Sklearn (computation on CPU).
+        * ``randsvd``: uses the randomized_svd algorithm implemented in
+          Sklearn (computation on CPU), proposed in [HAL09]_.
 
-        ``cupy``: uses the Cupy library for GPU computation of the SVD as in
-        the LAPACK version. `
+        * ``cupy``: uses the Cupy library for GPU computation of the SVD as in
+          the LAPACK version. `
 
-        `eigencupy``: offers the same method as with the ``eigen`` option
-        but on GPU (through Cupy).
+        * ``eigencupy``: offers the same method as with the ``eigen`` option
+          but on GPU (through Cupy).
 
-        ``randcupy``: is an adaptation of the randomized_svd algorithm,
-        where all the computations are done on a GPU (through Cupy). `
+        * ``randcupy``: is an adaptation of the randomized_svd algorithm,
+          where all the computations are done on a GPU (through Cupy). `
 
-        `pytorch``: uses the Pytorch library for GPU computation of the SVD.
+        * ``pytorch``: uses the Pytorch library for GPU computation of the SVD.
 
-        ``eigenpytorch``: offers the same method as with the ``eigen``
-        option but on GPU (through Pytorch).
+        * ``eigenpytorch``: offers the same method as with the ``eigen``
+          option but on GPU (through Pytorch).
 
-        ``randpytorch``: is an adaptation of the randomized_svd algorithm,
-        where all the linear algebra computations are done on a GPU
-        (through Pytorch).
+        * ``randpytorch``: is an adaptation of the randomized_svd algorithm,
+          where all the linear algebra computations are done on a GPU
+          (through Pytorch).
 
     scaling : {None, "temp-mean", spat-mean", "temp-standard",
         "spat-standard"}, None or str optional
         Pixel-wise scaling mode using ``sklearn.preprocessing.scale``
         function. If set to None, the input matrix is left untouched. Otherwise:
 
-        ``temp-mean``: temporal px-wise mean is subtracted.
+        * ``temp-mean``: temporal px-wise mean is subtracted.
 
-        ``spat-mean``: spatial mean is subtracted.
+        * ``spat-mean``: spatial mean is subtracted.
 
-        ``temp-standard``: temporal mean centering plus scaling pixel values
-        to unit variance.
+        * ``temp-standard``: temporal mean centering plus scaling pixel values
+          to unit variance. HIGHLY RECOMMENDED FOR ASDI AND RDI CASES!
 
-        ``spat-standard``: spatial mean centering plus scaling pixel values
-        to unit variance.
+        * ``spat-standard``: spatial mean centering plus scaling pixel values
+          to unit variance.
 
     mask_center_px : None or int, optional
         If None, no masking is done. If an integer > 1 then this value is the
@@ -612,9 +612,9 @@ def pca_annulus(cube, angs, ncomp, annulus_width, r_guess, cube_ref=None,
     ----------
     cube : 3d or 4d numpy ndarray
         Input data cube to be processed by PCA.
-    angs : numpy ndarray
+    angs : numpy ndarray or None
         The parallactic angles expressed as a numpy.array.
-    ncomp : int or 1d numpy array of int
+    ncomp : int or list/1d numpy array of int
         The number of principal component.
     annulus_width : float
         The annulus width in pixel on which the PCA is performed.
@@ -648,8 +648,11 @@ def pca_annulus(cube, angs, ncomp, annulus_width, r_guess, cube_ref=None,
 
     Returns
     -------
-    Depending on ``collapse`` parameter a final collapsed frame or the cube of
-    residuals is returned.
+    pca_res: 2d or 3d ndarray
+        Depending on ``collapse`` and ``angs`` parameters, either a final 
+        collapsed frame (``collapse`` not None) or the cube of residuals 
+        (derotated if angs is not None, non-derotated otherwises).
+        Note: for 4d input cube, collapse must be non-None.
     """
 
     def _pca_annulus_3d(cube, angs, ncomp, annulus_width, r_guess, cube_ref,
@@ -700,13 +703,13 @@ def pca_annulus(cube, angs, ncomp, annulus_width, r_guess, cube_ref=None,
         if cube_ref is not None:
             if cube_ref.ndim == 3:
                 cube_ref = [cube_ref]*nch
-        if not isinstance(ncomp, list):
+        if np.isscalar(ncomp):
             ncomp = [ncomp]*nch
         elif isinstance(ncomp, list) and len(ncomp) != nch:
             msg = "If ncomp is a list, in the case of a 4d input cube without "
             msg += "input scale_list, it should have the same length as the "
             msg += "first dimension of the cube."
-            raise TypeError()
+            raise TypeError(msg)
         if collapse is None:
             raise ValueError("mode not supported. Provide value for collapse")
         ifs_res = np.zeros([nch, cube.shape[2], cube.shape[3]])
@@ -780,4 +783,4 @@ def _compute_inverse_stim_map(cube, angle_list, **rot_options):
     t, n, _ = cube.shape
     cube_inv_der = cube_derotate(cube, -angle_list, **rot_options)
     inverse_stim_map = _compute_stim_map(cube_inv_der)
-    return inverse_stim_map
+    return inverse_stim_map
\ No newline at end of file
