@@ -2,6 +2,36 @@
 
 """
 Module with frame/cube filtering functionalities.
+     
+.. [DAB15]
+   | Dabbech et al. 2015
+   | **MORESANE: MOdel REconstruction by Synthesis-ANalysis Estimators. A sparse 
+     deconvolution algorithm for radio interferometric imaging**
+   | *The Astrophysical Journal, Volume 641, Issue 1, pp. 556-564*
+   | `https://arxiv.org/abs/1412.5387
+     <https://arxiv.org/abs/1412.5387>`_
+     
+.. [KEN15]
+   | J. S. Kenyon 2015
+   | **PyMORESANE**
+   | *GitHub repository*
+   | `https://github.com/ratt-ru/PyMORESANE
+     <https://github.com/ratt-ru/PyMORESANE>`_
+     
+.. [LUC74]
+   | L. Lucy 1974
+   | **An iterative technique for the rectification of observed distributions**
+   | *The Astronomical Journal, Volume 79, p. 745*
+   | `https://ui.adsabs.harvard.edu/abs/1974AJ.....79..745L/abstract
+     <https://ui.adsabs.harvard.edu/abs/1974AJ.....79..745L/abstract>`_
+     
+.. [RIC72]
+   | W. H. Richardson 1972
+   | **Bayesian-Based Iterative Method of Image Restoration**
+   | *J. Opt. Soc. Am., Volume 27, pp. 1593-1607*
+   | `https://opg.optica.org/josa/abstract.cfm?uri=josa-62-1-55
+     <https://opg.optica.org/josa/abstract.cfm?uri=josa-62-1-55>`_
+
 """
 
 
@@ -33,7 +63,8 @@ from ..config import Progressbar
 
 def cube_filter_iuwt(cube, coeff=5, rel_coeff=1, full_output=False):
     """
-    Isotropic Undecimated Wavelet Transform filtering.
+    Isotropic Undecimated Wavelet Transform filtering, as implemented in 
+    [KEN15]_ and detailed in [DAB15]_.
 
     Parameters
     ----------
@@ -105,7 +136,7 @@ def cube_filter_highpass(array, mode='laplacian', verbose=True, **kwargs):
     elif array.ndim == 4:
         for i in Progressbar(range(array.shape[1]), verbose=verbose):
             for lam in range(array.shape[0]):
-                array_out[lam][i] = frame_filter_highpass(array[lam][i],
+                array_out[lam][i] = frame_filter_highpass(array[lam][i], 
                                                           mode=mode, **kwargs)
     else:
         raise TypeError('Input array is not a 3d or 4d cube')
@@ -136,8 +167,8 @@ def ifft(array):
     This produces an array of complex numbers whose real values correspond to
     the image in the original space (decentering).
 
-    Notes
-    -----
+    Note
+    ----
     A real function corresponds to a symmetric function in fourier space. As
     long as the operations we apply in the fourier space do not break this
     symmetry, the data returned by ``ifft`` should not containy any imaginary
@@ -186,7 +217,7 @@ def frame_filter_highpass(array, mode, median_size=5, kernel_size=5,
         Size of the Laplacian kernel used in ``laplacian`` mode. It must be an
         positive odd integer value.
     fwhm_size : float, optional
-        Size of the Gaussian kernel used in ``gaus-subt`` mode.
+        Size of the Gaussian kernel used in ``gauss-subt`` mode.
     btw_cutoff : float, optional
         Frequency cutoff for low-pass 2d Butterworth filter used in
         ``fourier-butter`` mode.
@@ -263,8 +294,8 @@ def frame_filter_highpass(array, mode, median_size=5, kernel_size=5,
         -------
         r_rounded : array-like (float)
 
-        Notes
-        -----
+        Note
+        ----
         IDL ``ROUND`` rounds to the *nearest* integer (commercial rounding),
         unlike numpy's round/rint, which round to the nearest *even*
         value (half-to-even, financial rounding) as defined in IEEE-754
@@ -573,20 +604,13 @@ def cube_filter_lowpass(array, mode='gauss', median_size=5, fwhm_size=5,
 def frame_deconvolution(array, psf, n_it=30):
     """
     Iterative image deconvolution following the scikit-image implementation
-    of the Richardson-Lucy algorithm.
+    of the Richardson-Lucy algorithm, described in [RIC72]_ and [LUC74]_.
 
     Considering an image that has been convolved by the point spread function
     of an instrument, the algorithm will sharpen the blurred
     image through a user-defined number of iterations, which changes the
     regularisation.
 
-    Reference: William Hadley Richardson, “Bayesian-Based Iterative Method of
-    Image Restoration”, J. Opt. Soc. Am. A 27, 1593-1607 (1972),
-    DOI:10.1364/JOSA.62.000055
-
-    See also description at:
-    https://en.wikipedia.org/wiki/Richardson%E2%80%93Lucy_deconvolution
-
 
     Parameters
     ----------
