@@ -2,6 +2,7 @@
 Code with the Isotropic Undecimated Wavelet Transform, taken (Aug 24, 2015) from
 https://github.com/ratt-ru/PyMORESANE/
 Credits to J. S. Kenyon
+
 """
 
 
@@ -13,8 +14,11 @@ import ctypes
 def iuwt_decomposition(in1, scale_count, scale_adjust=0,
                        mode='ser', core_count=2, store_smoothed=False):
     """
-    This function serves as a handler for the different implementations of the IUWT decomposition. It allows the
-    different methods to be used almost interchangeably.
+    This function serves as a handler for the different implementations of the 
+    IUWT decomposition. It allows the different methods to be used almost 
+    interchangeably.
+    
+    The code was taken from [KEN15]_ and is detailed in [DAB15]_.
 
     INPUTS:
     in1                 (no default):       Array on which the decomposition is to be performed.
