@@ -1,7 +1,16 @@
 #! /usr/bin/env python
 
 """
-Module with various functions to create shapes, annuli and segments.
+Module with various functions to create shapes, annuli and segments.     
+
+.. [GEB20]
+   | Gebhard et al. 2020
+   | **Physically constrained causal noise models for high-contrast imaging of 
+     exoplanets**
+   | *arXiv e-prints7*
+   | `https://arxiv.org/abs/2010.05591
+     <https://arxiv.org/abs/2010.05591>`_
+     
 """
 
 __author__ = 'Carlos Alberto Gomez Gonzalez, Carles Cantero'
@@ -28,7 +37,7 @@ from .coords import frame_center, dist
 from ..config.utils_conf import frame_or_shape
 
 
-def mask_circle(array, radius, fillwith=0, mode='in'):
+def mask_circle(array, radius, fillwith=0, mode='in', cy=None, cx=None):
     """
     Mask the pixels inside/outside of a centered circle with ``fillwith``.
 
@@ -46,6 +55,9 @@ def mask_circle(array, radius, fillwith=0, mode='in'):
         When set to 'in' then the pixels inside the radius are set to
         ``fillwith``. When set to 'out' the pixels outside the circular mask
         are set to ``fillwith``.
+    cy, cx : floats, opt
+        XY coordinates of thenter of the mask. By default, it considers the 
+        center of the image.
 
     Returns
     -------
@@ -56,7 +68,8 @@ def mask_circle(array, radius, fillwith=0, mode='in'):
     if not isinstance(fillwith, (int, float)):
         raise ValueError('`fillwith` must be integer, float or np.nan')
 
-    cy, cx = frame_center(array)
+    if cy is None or cx is None:
+        cy, cx = frame_center(array)
 
     shape = (array.shape[-2], array.shape[-1])
     ind = disk((cy, cx), radius, shape=shape)
@@ -273,8 +286,8 @@ def get_circle(array, radius, cy=None, cx=None, mode="mask"):
         [mode="val"] 1d array with the values of the pixels in the circular
         region.
 
-    Notes
-    -----
+    Note
+    ----
     An alternative implementation would use ``skimage.draw.disk``. ``disk``
     performs better on large arrays (e.g. 1000px, 10.000px), while the
     current implementation is faster for small arrays (e.g. 100px). See
@@ -404,8 +417,8 @@ def get_annulus_segments(data, inner_radius, width, nsegm=1, theta_init=0,
     masked : list of ndarrays
         [mode='mask'] Copy of ``data`` with masked out regions.
 
-    Notes
-    -----
+    Note
+    ----
     Moving from ``get_annulus`` to ``get_annulus_segments``:
 
     .. code::python
@@ -503,8 +516,8 @@ def get_annular_wedge(data, inner_radius, width, wedge=(0, 360), mode="ind"):
     masked : list of ndarrays
         [mode='mask'] Copy of ``data`` with masked out regions.
 
-    Notes
-    -----
+    Note
+    ----
     Moving from ``get_annulus`` to ``get_annulus_segments``:
 
     .. code::python
@@ -684,8 +697,7 @@ def prepare_matrix(array, scaling=None, mask_center_px=None, mode='fullfr',
     ----------
     array : 3d numpy ndarray
         Input cube.
-    scaling : {None, "temp-mean", spat-mean", "temp-standard", "spat-standard"},
-        None or str optional
+    scaling : {None, "temp-mean", spat-mean", "temp-standard", "spat-standard"}, None or str optional
         Pixel-wise scaling mode using ``sklearn.preprocessing.scale`` function.
         If set to None, the input matrix is left untouched. Otherwise:
 
@@ -794,7 +806,7 @@ def mask_roi(array, source_xy, exc_radius=4, ann_width=4, inc_radius=8,
              mode='val', plot=False):
     """
     Return a mask corresponding to the region of interest for a test point
-    source as defined in Gebhardt et al. (2021).
+    source as defined in [GEB20]_.
 
     Given a frame and a location of interest with coordinates xy=(cx,cy),
     the mask consists of all pixels from three different regions with respect
@@ -809,11 +821,11 @@ def mask_roi(array, source_xy, exc_radius=4, ann_width=4, inc_radius=8,
         * (r4) Annulus region: Pixels from the annulus where xy is located.
 
     The goal of this mask is to disentangle the expected structure of the
-    speckle pattern. Gebhardt et al.(2021) comment that "r2 is chosen to
-    capture any "local" effects around xy due to the instrument. r3 is chosen
-    symmetrically opposite of xy because if there is a speckle at xy, there
-    should also be an (anti-)speckle at r2. r4 is used because we know that the
-    systematic noise significantly depends on the radial variable."
+    speckle pattern. [GEB20]_ comment that 'r2 is chosen to capture any local 
+    effects around xy due to the instrument. r3 is chosen symmetrically opposite 
+    of xy because if there is a speckle at xy, there should also be an 
+    (anti-)speckle at r2. r4 is used because we know that the systematic noise 
+    significantly depends on the radial variable.'
 
     Parameters
     ----------
